Crate kcr_application_networking_k8s_aws

Crate kcr_application_networking_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the application-networking.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

application-networking.k8s.aws/v1alpha1

  • AccessLogPolicy
  • IAMAuthPolicy
  • ServiceExport
  • ServiceImport
  • TargetGroupPolicy
  • VpcAssociationPolicy

Modules

v1alpha1